from setuptools import setup

setup(
    name='tacrpy',
    version='0.0.2',
    description='Analytická knihovna pro potřeby TA ČR',
    long_description='Knihovna, která slouží pro vypracování různých typů datových analýz v rámci TA ČR.',
    author='david.sulc',
    author_email='sulda.str@gmail.com',
    packages=['tacrpy']
)